@@ -30,11 +30,9 @@ enum
 {
 	COL_DIR_NAME,
 	COL_H_FULLPATH,
-	COL_BAR,
 	COL_H_PERC,
 	COL_DIR_SIZE,
 	COL_H_SIZE,
-	COL_PERC,
 	COL_H_ALLOCSIZE,
 	COL_ELEMENTS,
 	COL_H_ELEMENTS,
